@@ -341,7 +341,12 @@ class CloudClient:
                 if key.endswith("/"):
                     continue
 
-                file_name = os.path.join(file_path, key[len(prefix.rstrip('/')) + 1:])
+                # prefix 是文件
+                file_name = file_path
+                path = key[len(prefix.rstrip('/')) + 1:]
+                # prefix 是文件夹
+                if path != "":
+                    file_name = os.path.join(file_path, path)
                 if not os.path.exists(os.path.dirname(file_name)):
                     os.makedirs(os.path.dirname(file_name), 0o0755)
 
