@@ -184,7 +184,7 @@ class MDS:
         dataset.checkout(info["version"])
         return dataset
 
-    def get_dataset(self, name: str) -> Dataset:
+    def get_dataset(self, name: str, **kwargs) -> Dataset:
         """Get a dataset with given name.
 
         Arguments:
@@ -194,9 +194,21 @@ class MDS:
             The requested :class:`~metaloop.dataset.dataset.Dataset` instance
 
         """
-        info = self._x_api.get_dataset(name)
+        info = self._x_api.get_dataset(name, **kwargs)
         return self._info_to_dataset(info)
 
+    def exist_dataset(self, name: str) -> bool:
+        """Determine whether the data set exists.
+
+        Arguments:
+            name: The name of the requested dataset.
+
+        Returns:
+            Ture or False
+
+        """
+        return self._x_api.exist_dataset(name)
+
     def list_dataset(self, name: Optional[str] = "") -> List[Dataset]:
         """List datasets
 
@@ -308,7 +320,8 @@ class MDS:
             self,
             dataset_ids: List[str],
             file_path: str,
-            storage_type: Optional[str] = "local"
+            storage_type: Optional[str] = "local",
+            **kwargs
     ) -> None:
         """export dataset in batch
 
@@ -325,13 +338,14 @@ class MDS:
             raise InvalidParamsError(message="dataset_ids is empty")
 
         dataset = self.get_dataset_by_id(dataset_ids[0])
-        dataset.export_data(file_path, storage_type, dataset_ids=dataset_ids)
+        dataset.export_data(file_path, storage_type, dataset_ids=dataset_ids, **kwargs)
 
     def export_annotated_data(
             self,
             dataset_ids: List[str],
             file_path: str,
-            storage_type: Optional[str] = "local"
+            storage_type: Optional[str] = "local",
+            **kwargs
     ) -> None:
         """export annotation dataset in batch, only support annotated or pre_annotated data
 
@@ -360,14 +374,14 @@ class MDS:
 
         if len(pre_annotated_dataset) > 0:
             dataset = self.get_dataset_by_id(pre_annotated_dataset[0])
-            dataset.export_data(file_path, storage_type, dataset_ids=pre_annotated_dataset)
+            dataset.export_data(file_path, storage_type, dataset_ids=pre_annotated_dataset, **kwargs)
 
         if len(annotated_dataset) > 0:
             json_file = os.path.join(file_path, 'output.json')
             if os.path.exists(json_file):
                 os.rename(json_file, os.path.join(file_path, 'output.json.pre'))
             dataset = self.get_dataset_by_id(annotated_dataset[0])
-            dataset.export_data(file_path, storage_type, dataset_ids=annotated_dataset)
+            dataset.export_data(file_path, storage_type, dataset_ids=annotated_dataset, **kwargs)
             pre_json_file = os.path.join(file_path, 'output.json.pre')
             if os.path.exists(pre_json_file):
                 file_out = open(json_file, 'a')
@@ -460,6 +474,22 @@ class MDS:
         DEFAULTCATEGORY = "default"
         PROGRESSCATEGORY = "progress"
 
+    class ALGOSVCTEST:
+        CREATED = "created"
+        PENDING = "pending"
+        RUNNING = "running"
+        SUCCESS = "success"
+        FAILED = "failed"
+        DELETED = "deleted"
+        Bucket = "abaddon"
+
+    def update_algo_svc_test(self, id: int,
+                             status: Optional[int] = None,
+                             result: Optional[str] = None,
+                             perfres: Optional[str] = None):
+        info = self._x_api.update_algo_svc_test(id, status, result, perfres)
+        return info
+
     def update_calibset(self,
                         id: int,
                         status: Optional[int] = CALIB.PROCESSING,
@@ -480,3 +510,86 @@ class MDS:
         """
         info = self._x_api.update_calibset(id, status, pb_url, log, folders, category)
         return info
+
+    def get_ppf_url_by_category(self, category: str) -> str:
+        """get post process library(ppf) url by categories of different platforms
+        The model testing of the vitefait project  requires ppf file in different platforms,
+
+        Arguments:
+            category: reference value
+            [
+                acl2020_arm
+                acl2020_x86
+                acl2101_arm
+                acl2101_x86
+                ar14
+                bmnn24
+                bmnn24_soc
+                bmnn40
+                bmnn40_soc
+                cam14
+                cann50_arm
+                cann50_x86
+                cann60_arm
+                cann60_x86
+                cuda
+                dl025
+                nnie
+                nx
+                ov2140
+                ppflist
+                pyso
+                rk3399
+                trt60
+                trt72
+                trt80
+            ]
+             for more detailed content reference model_envs table ppf field.
+        """
+        info = self._x_api.get_ppf_url_by_category(category)
+        return info
+
+    def search_train_task_template(self, post_data: Dict[str, Any]) -> Dict[str, Any]:
+        """search train task template
+
+        Arguments:
+            post_data: task template data.
+        """
+        return self._x_api.search_train_task_template(post_data)
+
+    def create_train_task_template(self, data: Dict[str, Any]) -> Dict[str, Any]:
+        """create train task template
+
+        Arguments:
+            data: task template data.
+        """
+        return self._x_api.create_train_task_template(data)
+
+    def get_pipe_template_by_id(self, id: str, export: Optional[bool] = False) -> Dict[str, Any]:
+        """get pipe template
+
+        Arguments:
+            :param id: pipe template id.
+            :param export: export or not.
+        """
+        return self._x_api.get_pipe_template_by_id(id, export)
+
+    def create_pipe_template(self, data: Dict[str, Any]) -> Dict[str, Any]:
+        """create pipe template
+
+        Arguments:
+            data: pipe template data.
+        """
+        return self._x_api.create_pipe_template(data)
+
+    def call_model_search_result(self, record_id, file_path) -> Dict[str, Any]:
+        """callback model_search s3 file_path.
+
+        Arguments:
+                record_id:  模型搜索的id
+                file_path: s3路径,
+        """
+        if record_id == "" or file_path == "":
+            raise InvalidParamsError(message="record_id or file_path not blank")
+        info = self._x_api.call_model_search_result({"record_id": record_id, "respath": file_path})
+        return info
