@@ -1,14 +1,14 @@
 import json
 import os.path
 from typing import Dict, Any, Optional, List
+from urllib import parse
 
+from requests.models import Response
 from requests_toolbelt import MultipartEncoder
 from s3transfer.constants import MB
-from requests.models import Response
 
 from metaloop.client.requests import Client
 from metaloop.exception import ResourceNotExistError, InvalidParamsError, InternalServerError
-from urllib import parse
 
 
 class X_API:
@@ -22,13 +22,21 @@ class X_API:
         response = self._client.open_api_do("POST", "", json=post_data).json()
         return response["data"][0]
 
-    def callback_task(
+    def pretrain_callback_task(
             self,
             task_id: str,
             post_data: Dict[str, Any]
     ) -> Dict[str, Any]:
         response = self._client.open_api_do("POST", f"pretrain/task/{task_id}/callback", json=post_data).json()
         return response
+    
+    def leader_board_callback_task(
+            self,
+            task_id: str,
+            post_data: Dict[str, Any]
+    ) -> Dict[str, Any]:
+        response = self._client.open_api_do("POST", f"leaderboard/task/{task_id}/callback", json=post_data).json()
+        return response
 
     def delete_dataset(
             self,
@@ -52,11 +60,12 @@ class X_API:
     def get_dataset(
             self,
             name: str,
+            **kwargs
     ) -> Dict[str, Any]:
         if not name:
             raise InvalidParamsError(param_name="dataset", param_value=name)
 
-        response = self.list_datasets(name=name)
+        response = self.list_datasets(name=name, **kwargs)
 
         try:
             info = response["data"][0]
@@ -65,6 +74,19 @@ class X_API:
 
         return info
 
+    def exist_dataset(
+            self,
+            name: str,
+    ) -> bool:
+        if not name:
+            raise InvalidParamsError(param_name="dataset", param_value=name)
+
+        response = self.list_datasets(name=name)
+        if "data" in response:
+            return len(response['data']) != 0
+
+        return False
+
     def get_dataset_name(
             self,
             name: str,
@@ -85,12 +107,14 @@ class X_API:
             self,
             name: Optional[str] = None,
             offset: int = 0,
-            limit: int = 128
+            limit: int = 128,
+            **kwargs
     ) -> Dict[str, Any]:
         post_data: Dict[str, Any] = {
             "offset": offset,
             "limit": limit,
         }
+        post_data.update(kwargs)
         if name:
             post_data["name"] = [name]
 
@@ -274,13 +298,13 @@ class X_API:
             dataset_id: str,
             post_data: str
     ) -> None:
-        self._client.open_api_do("POST", "import", dataset_id, json=post_data)
+        self._client.open_api_do("POST", "import", dataset_id, json=post_data, params={"env": "dataset_transfer"})
 
     def get_import_status(
             self,
             dataset_id: str
     ) -> Dict[str, Any]:
-        response = self._client.open_api_do("GET", "import", dataset_id).json()
+        response = self._client.open_api_do("GET", "import", dataset_id, params={"env": "dataset_transfer"}).json()
 
         try:
             info = response["data"][0]
@@ -358,7 +382,7 @@ class X_API:
             export_list.append(json.loads(line))
 
         return export_list
-    
+
     def get_retry_str(self, retry: int) -> str:
         retry_str = ''
         if retry + 1 == 1:
@@ -407,6 +431,7 @@ class X_API:
                 "POST",
                 "upload",
                 data=multipart,
+                params={"env": "dataset_transfer"},
                 headers={"Content-Type": multipart.content_type},
             ).json()
             info = response["data"][0]
@@ -435,8 +460,8 @@ class X_API:
         return response
 
     def call_model_test_status(
-             self,
-             post_data: Dict[str, Any]
+            self,
+            post_data: Dict[str, Any]
     ) -> Dict[str, Any]:
         response = self._client.open_api_do("PUT", "model_test/status/callback", "", json=post_data).json()
         return response
@@ -447,7 +472,7 @@ class X_API:
     ) -> Dict[str, Any]:
         response = self._client.open_api_do("PUT", "model_test_result/content/callback", "", json=post_data).json()
         return response
-    
+
     def send_notice(
             self,
             title: str,
@@ -464,20 +489,74 @@ class X_API:
         response = self._client.open_api_do("POST", "notice", "", json=data).json()
         return response
 
-    def update_calibset(self,
-                        id: int,
-                        status: Optional[int] = None,
-                        pb_url: Optional[str] = None,
-                        log: Optional[str] = None,
-                        folders: Optional[str] = None,
-                        category:  Optional[str] = "default"
-                        )-> Dict[str, Any]:
+    def update_algo_svc_test(self, id: int, status: Optional[str] = None, result: Optional[str] = None,
+                             perfres: Optional[str] = None):
         data = {}
         data["id"] = id
-        data["status"] = status
-        data["pb_url"] = pb_url
-        data["log"] = log
-        data["folders"] = folders
-        api = "model_calib?category=" + category
-        response = self._client.open_api_do("PUT", api , "", json=data).json()
-        return response
\ No newline at end of file
+        if status is not None:
+            data["status"] = status
+        if result is not None:
+            data["result"] = result
+        if perfres is not None:
+            data["perfres"] = perfres
+        api = "algo_svc_test"
+        return self._client.open_api_do("PUT", api, json=data).json()
+
+
+def update_calibset(self,
+                    id: int,
+                    status: Optional[int] = None,
+                    pb_url: Optional[str] = None,
+                    log: Optional[str] = None,
+                    folders: Optional[str] = None,
+                    category: Optional[str] = "default"
+                    ) -> Dict[str, Any]:
+    data = {}
+    data["id"] = id
+    data["status"] = status
+    data["pb_url"] = pb_url
+    data["log"] = log
+    data["folders"] = folders
+    api = "model_calib?category=" + category
+    response = self._client.open_api_do("PUT", api, "", json=data).json()
+    return response
+
+
+def get_ppf_url_by_category(self, category: str) -> str:
+    api = "ppf/lists?category=" + category
+    response = self._client.open_api_do("GET", api, "").json()
+    return response["data"]["path_url"]
+
+
+def search_train_task_template(self, post_data: Dict[str, Any]) -> Dict[str, Any]:
+    api = "search/train_task_template"
+    response = self._client.open_api_do("POST", api, "", json=post_data).json()
+    return response["data"]
+
+
+def create_train_task_template(self, post_data: Dict[str, Any]) -> Dict[str, Any]:
+    api = "train/task_template"
+    response = self._client.open_api_do("POST", api, "", json=post_data).json()
+    return response["data"]
+
+
+def get_pipe_template_by_id(self, id: str, export: bool) -> Dict[str, Any]:
+    api = "pipeline_template/" + id
+    if export:
+        api += "?export=true"
+    response = self._client.open_api_do("GET", api, "", ).json()
+    return response["data"]
+
+
+def create_pipe_template(self, post_data: Dict[str, Any]) -> Dict[str, Any]:
+    api = "pipeline_template"
+    response = self._client.open_api_do("POST", api, "", json=post_data).json()
+    return response["data"]
+
+
+def call_model_search_result(
+        self,
+        post_data: Dict[str, Any]
+) -> Dict[str, Any]:
+    response = self._client.open_api_do("POST", "model_search/callback", "", json=post_data).json()
+    return response
