@@ -17,7 +17,6 @@ if TYPE_CHECKING:
 logging.basicConfig(level=logging.INFO)
 logger = logging.getLogger(__name__)
 
-
 DATASET_SUMMARY_TEMPLATE = """
 ===================================================================
 ######################## Dataset Summary ##########################
@@ -116,6 +115,14 @@ class Dataset(DatasetMeta):
     def id(self):
         return self._id
 
+    @property
+    def name(self):
+        return self._name
+
+    @property
+    def version(self):
+        return self._version
+
     @property
     def annotation_status(self):
         return self._annotation_status
@@ -274,7 +281,7 @@ class Dataset(DatasetMeta):
 
         if len(payloads) <= 0:
             raise InvalidParamsError(param_name="payloads", param_value=payloads)
-        
+
         post_data: Dict[str, Any] = {
             "transcode": transcode,
             "create_timestamp": int(time.time() * 1000),
@@ -380,7 +387,8 @@ class Dataset(DatasetMeta):
             file_path: str,
             storage_type: Optional[str] = "local",
             export_path: Optional[List[str]] = None,
-            dataset_ids: Optional[List[str]] = None
+            dataset_ids: Optional[List[str]] = None,
+            **kwargs: Any
     ) -> None:
         """Export data to local file from dataset.
 
@@ -408,7 +416,10 @@ class Dataset(DatasetMeta):
             "dataset_id": self._id if not dataset_ids else dataset_ids,
             "export_type": export_type,
             "task_type": "shared_links",
+            "write_full_path": True,
         }
+        for key, value in kwargs.items():
+            post_data[key] = value
         if export_type == "annotation_uri":
             post_data["storage_type"] = storage_type
         if export_path:
@@ -481,7 +492,7 @@ class Dataset(DatasetMeta):
             info = self._x_api.get_import_status(self._id)
             progress = info["progress"]
             if progress == -1:
-                raise InternalServerError(message=info["message"])
+                raise InternalServerError(message=info["error_msg"])
             if pbar:
                 pbar.update(progress - last_progress)
             if progress >= 100:
@@ -517,7 +528,7 @@ class Dataset(DatasetMeta):
             upload_prefix: Optional[str] = ""
     ) -> str:
         bucket = self._get_bucket(storage_type)
-        s3_config = CloudClient.get_cloud_storage_config(self._x_api, "", storage_type)
+        s3_config = CloudClient.get_cloud_storage_config(self._x_api, bucket, storage_type)
 
         if not bucket:
             bucket = s3_config.default_bucket
@@ -533,14 +544,14 @@ class Dataset(DatasetMeta):
             storage_type: str,
             upload_prefix: Optional[str] = ""
     ) -> str:
-        s3_config = CloudClient.get_cloud_storage_config(self._x_api, "", storage_type)
-
         bucket = self._get_bucket(storage_type)
+        s3_config = CloudClient.get_cloud_storage_config(self._x_api, bucket, storage_type)
+
         if not bucket:
             bucket = s3_config.default_bucket
 
         if not upload_prefix:
-            date_time = time.strftime("%Y%m%d", time.localtime())
+            date_time = time.strftime("%Y%m%d%H%M%S", time.localtime())
             upload_prefix = f"raw/{date_time}"
 
         return CloudClient.upload_files_parallel(s3_config.identifier, bucket, file_path, upload_prefix)
@@ -552,7 +563,7 @@ class Dataset(DatasetMeta):
         if self._space != "":
             space = self._x_api.get_space(self._space)
 
-            if storage_type == "external" and "cloud_bucket" in space:
+            if storage_type == "cos" and "cloud_bucket" in space:
                 return space["cloud_bucket"]
             elif storage_type == "local" and "bucket" in space:
                 return space["bucket"]
