@@ -32,3 +32,6 @@ if __name__ == '__main__':
     res = mds_client.call_model_test_result_content(mtRes)
     print(res['code'] == 200)
 
+    res = mds_client.get_ppf_url_by_category("acl2101_x86")
+    print(res)
+
