@@ -1,5 +1,6 @@
 import argparse
 import os.path
+import json
 
 from metaloop.client.mds import MDS
 
@@ -10,6 +11,7 @@ def parse_args():
     parser.add_argument('--user_token', required=True, help='user token used to access metaloop API')
     parser.add_argument('--train_dataset_ids', required=True, help='IDs of training dataset to export')
     parser.add_argument('--test_dataset_ids', default='', help='IDs of test dataset to export')
+    parser.add_argument('--online_dataset_ids', default='', help='IDs of online dataset to export')
     parser.add_argument('--output_path', default='', help='local path to store downloaded data')
     return parser.parse_args()
 
@@ -24,7 +26,15 @@ def get_data(mds_client, dataset_ids, flag='train'):
 
     mds_client.export_annotated_data(dataset_ids.split(','), output_path)
     if os.path.exists(os.path.join(output_path, 'output.json')):
-        os.rename(os.path.join(output_path, 'output.json'), os.path.join(output_path, 'input.json'))
+        file_out = open(os.path.join(output_path, 'input.json'), 'w')
+        with open(os.path.join(output_path, 'output.json'), 'r') as f:
+            for line in f:
+                data = json.loads(line)
+                data['url_image'] = os.path.join(output_path, data['url_image'])
+                json.dump(data, file_out, ensure_ascii=False)
+                file_out.write('\n')
+        file_out.close()
+        os.remove(os.path.join(output_path, 'output.json'))
 
 
 def main(args):
@@ -32,6 +42,7 @@ def main(args):
 
     get_data(mds_client, args.train_dataset_ids, 'train')
     get_data(mds_client, args.test_dataset_ids, 'test')
+    get_data(mds_client, args.online_dataset_ids, 'online')
 
 
 if __name__ == '__main__':
