@@ -6,6 +6,7 @@
 """Utility classes."""
 from metaloop.utils.requests import *
 from metaloop.utils.file_helper import *
+from metaloop.utils.zip import *
 
 __all__ = [
     "Tqdm",
@@ -15,5 +16,8 @@ __all__ = [
     "get_session",
     "get_file_type",
     "get_bucket_and_key",
-    "get_user_origin_path"
+    "get_user_origin_path",
+    "unzip_file",
+    "zip_files_with_password"
+
 ]
